<?php

namespace NoccyLabs\MessageCatalog;

use PDO;
use Traversable;

class Message
{
    private array $content;

    public function __construct(
        string ...$content
    )
    {
        $this->content = $content;
    }

    public function getAllContent(): array
    {
        return $this->content;
    }

    public function getContent(string $type): string
    {
        if (isset($this->content[$type])) {
            return $this->content[$type];
        }
        throw new \RuntimeException();
    }

    public function getTransformed(array $context): array
    {
        $result = [];
        foreach ($this->content as $type=>$content) {
            $result[$type] = $this->transform($content, $context);
        }
        return $result;
    }

    public function transform(string $content, array $context): string
    {
        $content = preg_replace_callback('<%\{(.+?)\}>', function ($m) use ($context) {
            $key = $m[1];
            if (!isset($context[$key])) {
                throw new \RuntimeException("Template uses undefined slot {$key}");
            }
            return $context[$key];
        }, $content);
        return $content;
    }
}
